
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

#if !defined(_HANDY_INSIDE) && !defined(HANDY_COMPILATION)
#error "Only <handy.h> can be included directly."
#endif

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "hdy-arrows.h" */
GType hdy_arrows_direction_get_type (void);
#define HDY_TYPE_ARROWS_DIRECTION (hdy_arrows_direction_get_type ())

/* enumerations from "hdy-fold.h" */
GType hdy_fold_get_type (void);
#define HDY_TYPE_FOLD (hdy_fold_get_type ())

/* enumerations from "hdy-header-bar.h" */
GType hdy_centering_policy_get_type (void);
#define HDY_TYPE_CENTERING_POLICY (hdy_centering_policy_get_type ())

/* enumerations from "hdy-leaflet.h" */
GType hdy_leaflet_transition_type_get_type (void);
#define HDY_TYPE_LEAFLET_TRANSITION_TYPE (hdy_leaflet_transition_type_get_type ())
GType hdy_leaflet_mode_transition_type_get_type (void);
#define HDY_TYPE_LEAFLET_MODE_TRANSITION_TYPE (hdy_leaflet_mode_transition_type_get_type ())
GType hdy_leaflet_child_transition_type_get_type (void);
#define HDY_TYPE_LEAFLET_CHILD_TRANSITION_TYPE (hdy_leaflet_child_transition_type_get_type ())

/* enumerations from "hdy-paginator.h" */
GType hdy_paginator_indicator_style_get_type (void);
#define HDY_TYPE_PAGINATOR_INDICATOR_STYLE (hdy_paginator_indicator_style_get_type ())

/* enumerations from "hdy-squeezer.h" */
GType hdy_squeezer_transition_type_get_type (void);
#define HDY_TYPE_SQUEEZER_TRANSITION_TYPE (hdy_squeezer_transition_type_get_type ())

/* enumerations from "hdy-view-switcher.h" */
GType hdy_view_switcher_policy_get_type (void);
#define HDY_TYPE_VIEW_SWITCHER_POLICY (hdy_view_switcher_policy_get_type ())
G_END_DECLS

/* Generated data ends here */

